/* display-toolbar.c generated by valac 0.23.2.10-fed12, the Vala compiler
 * generated from display-toolbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <float.h>
#include <math.h>
#include <clutter/clutter.h>
#include <stdlib.h>
#include <string.h>


#define BOXES_TYPE_DISPLAY_TOOLBAR (boxes_display_toolbar_get_type ())
#define BOXES_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar))
#define BOXES_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))
#define BOXES_IS_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_IS_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_DISPLAY_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))

typedef struct _BoxesDisplayToolbar BoxesDisplayToolbar;
typedef struct _BoxesDisplayToolbarClass BoxesDisplayToolbarClass;
typedef struct _BoxesDisplayToolbarPrivate BoxesDisplayToolbarPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __vala_GdkEventMotion_free0(var) ((var == NULL) ? NULL : (var = (_vala_GdkEventMotion_free (var), NULL)))
typedef struct _Block15Data Block15Data;
typedef struct _Block16Data Block16Data;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

struct _BoxesDisplayToolbar {
	GtkHeaderBar parent_instance;
	BoxesDisplayToolbarPrivate * priv;
};

struct _BoxesDisplayToolbarClass {
	GtkHeaderBarClass parent_class;
};

struct _BoxesDisplayToolbarPrivate {
	gboolean _overlay;
	gboolean _handle_drag;
	GtkImage* back_image;
	GtkImage* fullscreen_image;
	GtkButton* back;
	GtkButton* fullscreen;
	GtkButton* props;
	gboolean button_down;
	gint button_down_x;
	gint button_down_y;
	guint button_down_button;
};

struct _Block15Data {
	int _ref_count_;
	BoxesDisplayToolbar* self;
	GdkEventMotion* event;
};

struct _Block16Data {
	int _ref_count_;
	Block15Data * _data15_;
	GtkWindow* window;
	gint old_width;
	gulong id;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	ClutterActor* (*get_actor) (BoxesUI* self);
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};


static gpointer boxes_display_toolbar_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_display_toolbar_get_type (void) G_GNUC_CONST;
#define BOXES_DISPLAY_TOOLBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarPrivate))
enum  {
	BOXES_DISPLAY_TOOLBAR_DUMMY_PROPERTY,
	BOXES_DISPLAY_TOOLBAR_OVERLAY,
	BOXES_DISPLAY_TOOLBAR_HANDLE_DRAG
};
BoxesDisplayToolbar* boxes_display_toolbar_new (gboolean overlay, gboolean handle_drag);
BoxesDisplayToolbar* boxes_display_toolbar_construct (GType object_type, gboolean overlay, gboolean handle_drag);
static gboolean boxes_display_toolbar_real_button_press_event (GtkWidget* base, GdkEventButton* event);
gboolean boxes_display_toolbar_get_handle_drag (BoxesDisplayToolbar* self);
static gboolean boxes_display_toolbar_real_button_release_event (GtkWidget* base, GdkEventButton* event);
static gboolean boxes_display_toolbar_real_motion_notify_event (GtkWidget* base, GdkEventMotion* event);
static GdkEventMotion* _vala_GdkEventMotion_copy (GdkEventMotion* self);
static void _vala_GdkEventMotion_free (GdkEventMotion* self);
static Block15Data* block15_data_ref (Block15Data* _data15_);
static void block15_data_unref (void * _userdata_);
static Block16Data* block16_data_ref (Block16Data* _data16_);
static void block16_data_unref (void * _userdata_);
GType boxes_app_get_type (void) G_GNUC_CONST;
void boxes_app_set_fullscreen (BoxesApp* self, gboolean value);
static void ____lambda9_ (Block16Data* _data16_);
static void _____lambda9__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_display_toolbar_on_back_clicked (BoxesDisplayToolbar* self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
static void _boxes_display_toolbar_on_back_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_display_toolbar_on_fullscreen_clicked (BoxesDisplayToolbar* self);
gboolean boxes_app_get_fullscreen (BoxesApp* self);
static void _boxes_display_toolbar_on_fullscreen_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_display_toolbar_on_props_clicked (BoxesDisplayToolbar* self);
static void _boxes_display_toolbar_on_props_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
gboolean boxes_display_toolbar_get_overlay (BoxesDisplayToolbar* self);
static void boxes_display_toolbar_set_overlay (BoxesDisplayToolbar* self, gboolean value);
static void boxes_display_toolbar_set_handle_drag (BoxesDisplayToolbar* self, gboolean value);
static GObject * boxes_display_toolbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_display_toolbar___lambda10_ (BoxesDisplayToolbar* self);
static void __boxes_display_toolbar___lambda10__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_display_toolbar_finalize (GObject* obj);
static void _vala_boxes_display_toolbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_display_toolbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


BoxesDisplayToolbar* boxes_display_toolbar_construct (GType object_type, gboolean overlay, gboolean handle_drag) {
	BoxesDisplayToolbar * self = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = overlay;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp1_ = handle_drag;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self = (BoxesDisplayToolbar*) g_object_new (object_type, "overlay", _tmp0_, "handle-drag", _tmp1_, NULL);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return self;
#line 169 "display-toolbar.c"
}


BoxesDisplayToolbar* boxes_display_toolbar_new (gboolean overlay, gboolean handle_drag) {
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return boxes_display_toolbar_construct (BOXES_TYPE_DISPLAY_TOOLBAR, overlay, handle_drag);
#line 176 "display-toolbar.c"
}


static gboolean boxes_display_toolbar_real_button_press_event (GtkWidget* base, GdkEventButton* event) {
	BoxesDisplayToolbar * self;
	gboolean result = FALSE;
	gboolean res = FALSE;
	GdkEventButton* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	GdkEvent* base_event = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self = (BoxesDisplayToolbar*) base;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = event;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp1_ = GTK_WIDGET_CLASS (boxes_display_toolbar_parent_class)->button_press_event ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, GTK_TYPE_HEADER_BAR, GtkHeaderBar), _tmp0_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	res = _tmp1_;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp2_ = self->priv->_handle_drag;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (!_tmp2_) {
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		result = res;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		return result;
#line 208 "display-toolbar.c"
	}
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	base_event = (GdkEvent*) (&event);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp4_ = res;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (!_tmp4_) {
#line 216 "display-toolbar.c"
		GdkEvent* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp5_ = base_event;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp6_ = gdk_event_triggers_context_menu (_tmp5_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp3_ = !_tmp6_;
#line 225 "display-toolbar.c"
	} else {
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp3_ = FALSE;
#line 229 "display-toolbar.c"
	}
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (_tmp3_) {
#line 233 "display-toolbar.c"
		GdkEventButton* _tmp7_ = NULL;
		guint _tmp8_ = 0U;
		GdkEventButton* _tmp9_ = NULL;
		gdouble _tmp10_ = 0.0;
		GdkEventButton* _tmp11_ = NULL;
		gdouble _tmp12_ = 0.0;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		self->priv->button_down = TRUE;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp7_ = event;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp8_ = _tmp7_->button;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		self->priv->button_down_button = _tmp8_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp9_ = event;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp10_ = _tmp9_->x;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		self->priv->button_down_x = (gint) _tmp10_;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp11_ = event;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp12_ = _tmp11_->y;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		self->priv->button_down_y = (gint) _tmp12_;
#line 260 "display-toolbar.c"
	}
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	result = res;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return result;
#line 266 "display-toolbar.c"
}


static gboolean boxes_display_toolbar_real_button_release_event (GtkWidget* base, GdkEventButton* event) {
	BoxesDisplayToolbar * self;
	gboolean result = FALSE;
	GdkEventButton* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self = (BoxesDisplayToolbar*) base;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self->priv->button_down = FALSE;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = event;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp1_ = GTK_WIDGET_CLASS (boxes_display_toolbar_parent_class)->button_press_event ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, GTK_TYPE_HEADER_BAR, GtkHeaderBar), _tmp0_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	result = _tmp1_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return result;
#line 289 "display-toolbar.c"
}


static GdkEventMotion* _vala_GdkEventMotion_copy (GdkEventMotion* self) {
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return g_boxed_copy (gdk_event_get_type (), self);
#line 296 "display-toolbar.c"
}


static gpointer __vala_GdkEventMotion_copy0 (gpointer self) {
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return self ? _vala_GdkEventMotion_copy (self) : NULL;
#line 303 "display-toolbar.c"
}


static void _vala_GdkEventMotion_free (GdkEventMotion* self) {
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_boxed_free (gdk_event_get_type (), self);
#line 310 "display-toolbar.c"
}


static Block15Data* block15_data_ref (Block15Data* _data15_) {
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_atomic_int_inc (&_data15_->_ref_count_);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return _data15_;
#line 319 "display-toolbar.c"
}


static void block15_data_unref (void * _userdata_) {
	Block15Data* _data15_;
	_data15_ = (Block15Data*) _userdata_;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (g_atomic_int_dec_and_test (&_data15_->_ref_count_)) {
#line 328 "display-toolbar.c"
		BoxesDisplayToolbar* self;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		self = _data15_->self;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		__vala_GdkEventMotion_free0 (_data15_->event);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_g_object_unref0 (self);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		g_slice_free (Block15Data, _data15_);
#line 338 "display-toolbar.c"
	}
}


static Block16Data* block16_data_ref (Block16Data* _data16_) {
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_atomic_int_inc (&_data16_->_ref_count_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return _data16_;
#line 348 "display-toolbar.c"
}


static void block16_data_unref (void * _userdata_) {
	Block16Data* _data16_;
	_data16_ = (Block16Data*) _userdata_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (g_atomic_int_dec_and_test (&_data16_->_ref_count_)) {
#line 357 "display-toolbar.c"
		BoxesDisplayToolbar* self;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		self = _data16_->_data15_->self;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_g_object_unref0 (_data16_->window);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		block15_data_unref (_data16_->_data15_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_data16_->_data15_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		g_slice_free (Block16Data, _data16_);
#line 369 "display-toolbar.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return self ? g_object_ref (self) : NULL;
#line 377 "display-toolbar.c"
}


static void ____lambda9_ (Block16Data* _data16_) {
	Block15Data* _data15_;
	BoxesDisplayToolbar* self;
	gint root_x = 0;
	gint root_y = 0;
	gint width = 0;
	GtkWindow* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	GtkWindow* _tmp3_ = NULL;
	GdkWindow* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	GtkWindow* _tmp6_ = NULL;
	guint _tmp7_ = 0U;
	gint _tmp8_ = 0;
	gint _tmp9_ = 0;
	gint _tmp10_ = 0;
	GdkEventMotion* _tmp11_ = NULL;
	guint32 _tmp12_ = 0U;
	BoxesApp* _tmp13_ = NULL;
	gulong _tmp14_ = 0UL;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_data15_ = _data16_->_data15_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self = _data15_->self;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = _data16_->window;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_window_get_position (_tmp0_, &_tmp1_, &_tmp2_);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	root_x = _tmp1_;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	root_y = _tmp2_;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp3_ = _data16_->window;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp4_ = gtk_widget_get_window ((GtkWidget*) _tmp3_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gdk_window_get_geometry (_tmp4_, NULL, NULL, &_tmp5_, NULL);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	width = _tmp5_;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp6_ = _data16_->window;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp7_ = self->priv->button_down_button;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp8_ = self->priv->button_down_x;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp9_ = _data16_->old_width;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp10_ = self->priv->button_down_y;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp11_ = _data15_->event;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp12_ = _tmp11_->time;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_window_begin_move_drag (_tmp6_, (gint) _tmp7_, root_x + ((gint) ((_tmp8_ / ((gdouble) _tmp9_)) * width)), root_y + _tmp10_, _tmp12_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp13_ = boxes_app_app;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp14_ = _data16_->id;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_signal_handler_disconnect ((GObject*) _tmp13_, _tmp14_);
#line 444 "display-toolbar.c"
}


static void _____lambda9__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	____lambda9_ (self);
#line 451 "display-toolbar.c"
}


static gboolean boxes_display_toolbar_real_motion_notify_event (GtkWidget* base, GdkEventMotion* event) {
	BoxesDisplayToolbar * self;
	gboolean result = FALSE;
	Block15Data* _data15_;
	GdkEventMotion* _tmp0_ = NULL;
	GdkEventMotion* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp5_ = FALSE;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self = (BoxesDisplayToolbar*) base;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_data15_ = g_slice_new0 (Block15Data);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_data15_->_ref_count_ = 1;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_data15_->self = g_object_ref (self);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = event;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp1_ = __vala_GdkEventMotion_copy0 (_tmp0_);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	__vala_GdkEventMotion_free0 (_data15_->event);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_data15_->event = _tmp1_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp2_ = self->priv->_handle_drag;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (!_tmp2_) {
#line 485 "display-toolbar.c"
		GdkEventMotion* _tmp3_ = NULL;
		gboolean _tmp4_ = FALSE;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp3_ = _data15_->event;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp4_ = GTK_WIDGET_CLASS (boxes_display_toolbar_parent_class)->motion_notify_event ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, GTK_TYPE_HEADER_BAR, GtkHeaderBar), _tmp3_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		result = _tmp4_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		block15_data_unref (_data15_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_data15_ = NULL;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		return result;
#line 500 "display-toolbar.c"
	}
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp5_ = self->priv->button_down;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (_tmp5_) {
#line 506 "display-toolbar.c"
		gdouble dx = 0.0;
		GdkEventMotion* _tmp6_ = NULL;
		gdouble _tmp7_ = 0.0;
		gint _tmp8_ = 0;
		gdouble dy = 0.0;
		GdkEventMotion* _tmp9_ = NULL;
		gdouble _tmp10_ = 0.0;
		gint _tmp11_ = 0;
		gdouble _tmp12_ = 0.0;
		gdouble _tmp13_ = 0.0;
		gdouble _tmp14_ = 0.0;
		gdouble _tmp15_ = 0.0;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp6_ = _data15_->event;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp7_ = _tmp6_->x;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp8_ = self->priv->button_down_x;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		dx = _tmp7_ - _tmp8_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp9_ = _data15_->event;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp10_ = _tmp9_->y;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp11_ = self->priv->button_down_y;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		dy = _tmp10_ - _tmp11_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp12_ = dx;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp13_ = dx;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp14_ = dy;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp15_ = dy;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		if (((_tmp12_ * _tmp13_) + (_tmp14_ * _tmp15_)) > ((gdouble) (40 * 40))) {
#line 545 "display-toolbar.c"
			Block16Data* _data16_;
			BoxesApp* _tmp16_ = NULL;
			GtkWidget* _tmp17_ = NULL;
			GtkWindow* _tmp18_ = NULL;
			GtkWindow* _tmp19_ = NULL;
			gint _tmp20_ = 0;
			BoxesApp* _tmp21_ = NULL;
			gulong _tmp22_ = 0UL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_data16_ = g_slice_new0 (Block16Data);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_data16_->_ref_count_ = 1;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_data16_->_data15_ = block15_data_ref (_data15_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			self->priv->button_down = FALSE;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_tmp16_ = boxes_app_app;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			boxes_app_set_fullscreen (_tmp16_, FALSE);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_tmp17_ = gtk_widget_get_toplevel ((GtkWidget*) self);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_tmp18_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, GTK_TYPE_WINDOW) ? ((GtkWindow*) _tmp17_) : NULL);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_data16_->window = _tmp18_;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_tmp19_ = _data16_->window;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			gtk_window_get_size (_tmp19_, &_tmp20_, NULL);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_data16_->old_width = _tmp20_;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_data16_->id = (gulong) 0;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_tmp21_ = boxes_app_app;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_tmp22_ = g_signal_connect_data ((GObject*) _tmp21_, "notify::fullscreen", (GCallback) _____lambda9__g_object_notify, block16_data_ref (_data16_), (GClosureNotify) block16_data_unref, 0);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_data16_->id = _tmp22_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			block16_data_unref (_data16_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_data16_ = NULL;
#line 590 "display-toolbar.c"
		}
	}
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (GTK_WIDGET_CLASS (boxes_display_toolbar_parent_class)->motion_notify_event != NULL) {
#line 595 "display-toolbar.c"
		GdkEventMotion* _tmp23_ = NULL;
		gboolean _tmp24_ = FALSE;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp23_ = _data15_->event;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp24_ = GTK_WIDGET_CLASS (boxes_display_toolbar_parent_class)->motion_notify_event ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, GTK_TYPE_HEADER_BAR, GtkHeaderBar), _tmp23_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		result = _tmp24_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		block15_data_unref (_data15_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_data15_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		return result;
#line 610 "display-toolbar.c"
	}
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	result = FALSE;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	block15_data_unref (_data15_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_data15_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return result;
#line 620 "display-toolbar.c"
}


static void boxes_display_toolbar_on_back_clicked (BoxesDisplayToolbar* self) {
	BoxesApp* _tmp0_ = NULL;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = boxes_app_app;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_COLLECTION);
#line 632 "display-toolbar.c"
}


static void _boxes_display_toolbar_on_back_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	boxes_display_toolbar_on_back_clicked ((BoxesDisplayToolbar*) self);
#line 639 "display-toolbar.c"
}


static void boxes_display_toolbar_on_fullscreen_clicked (BoxesDisplayToolbar* self) {
	BoxesApp* _tmp0_ = NULL;
	BoxesApp* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = boxes_app_app;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp1_ = boxes_app_app;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp2_ = boxes_app_get_fullscreen (_tmp1_);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp3_ = _tmp2_;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	boxes_app_set_fullscreen (_tmp0_, !_tmp3_);
#line 660 "display-toolbar.c"
}


static void _boxes_display_toolbar_on_fullscreen_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	boxes_display_toolbar_on_fullscreen_clicked ((BoxesDisplayToolbar*) self);
#line 667 "display-toolbar.c"
}


static void boxes_display_toolbar_on_props_clicked (BoxesDisplayToolbar* self) {
	BoxesApp* _tmp0_ = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = boxes_app_app;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_PROPERTIES);
#line 679 "display-toolbar.c"
}


static void _boxes_display_toolbar_on_props_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	boxes_display_toolbar_on_props_clicked ((BoxesDisplayToolbar*) self);
#line 686 "display-toolbar.c"
}


gboolean boxes_display_toolbar_get_overlay (BoxesDisplayToolbar* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = self->priv->_overlay;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	result = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return result;
#line 701 "display-toolbar.c"
}


static void boxes_display_toolbar_set_overlay (BoxesDisplayToolbar* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = value;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self->priv->_overlay = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_object_notify ((GObject *) self, "overlay");
#line 715 "display-toolbar.c"
}


gboolean boxes_display_toolbar_get_handle_drag (BoxesDisplayToolbar* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = self->priv->_handle_drag;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	result = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return result;
#line 730 "display-toolbar.c"
}


static void boxes_display_toolbar_set_handle_drag (BoxesDisplayToolbar* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = value;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self->priv->_handle_drag = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_object_notify ((GObject *) self, "handle-drag");
#line 744 "display-toolbar.c"
}


static void _boxes_display_toolbar___lambda10_ (BoxesDisplayToolbar* self) {
	BoxesApp* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = boxes_app_app;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp1_ = boxes_app_get_fullscreen (_tmp0_);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp2_ = _tmp1_;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (_tmp2_) {
#line 760 "display-toolbar.c"
		GtkImage* _tmp3_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp3_ = self->priv->fullscreen_image;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		g_object_set (_tmp3_, "icon-name", "view-restore-symbolic", NULL);
#line 766 "display-toolbar.c"
	} else {
		GtkImage* _tmp4_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp4_ = self->priv->fullscreen_image;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		g_object_set (_tmp4_, "icon-name", "view-fullscreen-symbolic", NULL);
#line 773 "display-toolbar.c"
	}
}


static void __boxes_display_toolbar___lambda10__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_boxes_display_toolbar___lambda10_ ((BoxesDisplayToolbar*) self);
#line 781 "display-toolbar.c"
}


static GObject * boxes_display_toolbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesDisplayToolbar * self;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp4_ = NULL;
	GtkTextDirection _tmp5_ = 0;
	GtkImage* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
	BoxesApp* _tmp14_ = NULL;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	parent_class = G_OBJECT_CLASS (boxes_display_toolbar_parent_class);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_add_events ((GtkWidget*) self, (gint) ((GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK) | GDK_BUTTON_RELEASE_MASK));
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = self->priv->_overlay;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (_tmp0_) {
#line 807 "display-toolbar.c"
		GtkStyleContext* _tmp1_ = NULL;
		GtkStyleContext* _tmp2_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp1_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		gtk_style_context_add_class (_tmp1_, "toolbar");
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		gtk_style_context_add_class (_tmp2_, "osd");
#line 818 "display-toolbar.c"
	} else {
		GtkStyleContext* _tmp3_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp3_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		gtk_style_context_add_class (_tmp3_, GTK_STYLE_CLASS_MENUBAR);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		gtk_header_bar_set_show_close_button ((GtkHeaderBar*) self, TRUE);
#line 827 "display-toolbar.c"
	}
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp5_ = gtk_widget_get_direction ((GtkWidget*) self);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (_tmp5_ == GTK_TEXT_DIR_RTL) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp4_ = "go-previous-rtl-symbolic";
#line 835 "display-toolbar.c"
	} else {
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp4_ = "go-previous-symbolic";
#line 839 "display-toolbar.c"
	}
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp6_ = self->priv->back_image;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_object_set (_tmp6_, "icon-name", _tmp4_, NULL);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp7_ = self->priv->_overlay;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (!_tmp7_) {
#line 849 "display-toolbar.c"
		GtkButton* _tmp8_ = NULL;
		GtkStyleContext* _tmp9_ = NULL;
		GtkButton* _tmp10_ = NULL;
		GtkStyleContext* _tmp11_ = NULL;
		GtkButton* _tmp12_ = NULL;
		GtkStyleContext* _tmp13_ = NULL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp8_ = self->priv->back;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp9_ = gtk_widget_get_style_context ((GtkWidget*) _tmp8_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		gtk_style_context_add_class (_tmp9_, "raised");
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp10_ = self->priv->fullscreen;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp11_ = gtk_widget_get_style_context ((GtkWidget*) _tmp10_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		gtk_style_context_add_class (_tmp11_, "raised");
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp12_ = self->priv->props;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp13_ = gtk_widget_get_style_context ((GtkWidget*) _tmp12_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		gtk_style_context_add_class (_tmp13_, "raised");
#line 874 "display-toolbar.c"
	}
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp14_ = boxes_app_app;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_signal_connect_object ((GObject*) _tmp14_, "notify::fullscreen", (GCallback) __boxes_display_toolbar___lambda10__g_object_notify, self, G_CONNECT_AFTER);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return obj;
#line 882 "display-toolbar.c"
}


static void boxes_display_toolbar_class_init (BoxesDisplayToolbarClass * klass) {
	gint BoxesDisplayToolbar_private_offset;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	boxes_display_toolbar_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesDisplayToolbarPrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	GTK_WIDGET_CLASS (klass)->button_press_event = boxes_display_toolbar_real_button_press_event;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	GTK_WIDGET_CLASS (klass)->button_release_event = boxes_display_toolbar_real_button_release_event;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	GTK_WIDGET_CLASS (klass)->motion_notify_event = boxes_display_toolbar_real_motion_notify_event;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_display_toolbar_get_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_display_toolbar_set_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_display_toolbar_constructor;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_display_toolbar_finalize;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_TOOLBAR_OVERLAY, g_param_spec_boolean ("overlay", "overlay", "overlay", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_TOOLBAR_HANDLE_DRAG, g_param_spec_boolean ("handle-drag", "handle-drag", "handle-drag", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	BoxesDisplayToolbar_private_offset = g_type_class_get_instance_private_offset (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/display-toolbar.ui");
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "back_image", FALSE, BoxesDisplayToolbar_private_offset + G_STRUCT_OFFSET (BoxesDisplayToolbarPrivate, back_image));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "fullscreen_image", FALSE, BoxesDisplayToolbar_private_offset + G_STRUCT_OFFSET (BoxesDisplayToolbarPrivate, fullscreen_image));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "back", FALSE, BoxesDisplayToolbar_private_offset + G_STRUCT_OFFSET (BoxesDisplayToolbarPrivate, back));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "fullscreen", FALSE, BoxesDisplayToolbar_private_offset + G_STRUCT_OFFSET (BoxesDisplayToolbarPrivate, fullscreen));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "props", FALSE, BoxesDisplayToolbar_private_offset + G_STRUCT_OFFSET (BoxesDisplayToolbarPrivate, props));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_back_clicked", G_CALLBACK(_boxes_display_toolbar_on_back_clicked_gtk_button_clicked));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_fullscreen_clicked", G_CALLBACK(_boxes_display_toolbar_on_fullscreen_clicked_gtk_button_clicked));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_props_clicked", G_CALLBACK(_boxes_display_toolbar_on_props_clicked_gtk_button_clicked));
#line 930 "display-toolbar.c"
}


static void boxes_display_toolbar_instance_init (BoxesDisplayToolbar * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self->priv = BOXES_DISPLAY_TOOLBAR_GET_PRIVATE (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 939 "display-toolbar.c"
}


static void boxes_display_toolbar_finalize (GObject* obj) {
	BoxesDisplayToolbar * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_g_object_unref0 (self->priv->back_image);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_g_object_unref0 (self->priv->fullscreen_image);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_g_object_unref0 (self->priv->back);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_g_object_unref0 (self->priv->fullscreen);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_g_object_unref0 (self->priv->props);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	G_OBJECT_CLASS (boxes_display_toolbar_parent_class)->finalize (obj);
#line 959 "display-toolbar.c"
}


GType boxes_display_toolbar_get_type (void) {
	static volatile gsize boxes_display_toolbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_display_toolbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesDisplayToolbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_display_toolbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesDisplayToolbar), 0, (GInstanceInitFunc) boxes_display_toolbar_instance_init, NULL };
		GType boxes_display_toolbar_type_id;
		boxes_display_toolbar_type_id = g_type_register_static (GTK_TYPE_HEADER_BAR, "BoxesDisplayToolbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_display_toolbar_type_id__volatile, boxes_display_toolbar_type_id);
	}
	return boxes_display_toolbar_type_id__volatile;
}


static void _vala_boxes_display_toolbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesDisplayToolbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	switch (property_id) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		case BOXES_DISPLAY_TOOLBAR_OVERLAY:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		g_value_set_boolean (value, boxes_display_toolbar_get_overlay (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		case BOXES_DISPLAY_TOOLBAR_HANDLE_DRAG:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		g_value_set_boolean (value, boxes_display_toolbar_get_handle_drag (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		break;
#line 992 "display-toolbar.c"
		default:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		break;
#line 998 "display-toolbar.c"
	}
}


static void _vala_boxes_display_toolbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesDisplayToolbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	switch (property_id) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		case BOXES_DISPLAY_TOOLBAR_OVERLAY:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		boxes_display_toolbar_set_overlay (self, g_value_get_boolean (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		case BOXES_DISPLAY_TOOLBAR_HANDLE_DRAG:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		boxes_display_toolbar_set_handle_drag (self, g_value_get_boolean (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		break;
#line 1020 "display-toolbar.c"
		default:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		break;
#line 1026 "display-toolbar.c"
	}
}



